/***
 This demo shows you how to make an NPC walk randomly,
 using Deadron's EventLoop library.

 It also shows how you can have things respond to player clicks.

 The base_EventCycle() call comes from the eventloop library,
 which calls base_EventCycle() for each mob each tick.
***/
#include <deadron/eventloop>

world
	mob = /mob/player

mob/player
	icon = 'nurse.dmi'

mob/npc
	icon = 'keystone.dmi'

	var/tmp
		next_walk_time			// When is the next time for us to walk?
		walking_delay = 10		// How long between movement?
		movement_percent = 50	// What percentage of the time should it move?


	base_EventCycle()
		// This gets called once each tick.

		if (next_walk_time <= world.time)
			// It's time to walk if we want to.
			// There is a movement_percent chance that we will walk.
			if (prob(movement_percent))
				step_rand(src)

			// Set the next walk time.
			next_walk_time = world.time + walking_delay
		return

	Click()
		// When an object is clicked, by default client.Click()
		// calls the object's Click() function.
		world << "[src] says: Hey [usr] just clicked on me!"


client
	Click(atom/movable/object, location)
		// When the player clicks on something, this client.Click() function is called.
		// object is the thing they clicked on, location is the turf or the name of the
		// statpanel where the click occurred.

		// Have player's mob walk to what they clicked.
		var/min_distance = 1
		walk_to(mob, object, min_distance)

		// Do default functionality, which calls the object's Click function.
		..()


turf
	icon = 'floorgreen.dmi'
